@@ -43,7 +43,7 @@ extern "C" {
 #endif
 
 static char  rcsid_sql_h [ ] =
-         "$Id: tdsodbc.h,v 1.19.2.2 2003/02/13 06:13:18 jklowden Exp $";
+         "$Id: tdsodbc.h,v 1.19.2.4 2003/08/01 05:23:23 freddy77 Exp $";
 static void *no_unused_sql_h_warn[]={rcsid_sql_h, no_unused_sql_h_warn};
 
 /* this is usually a const struct that store all errors */
@@ -95,7 +95,6 @@ struct _henv {
 struct _hstmt;
 struct _hdbc {
 	struct _henv *henv;
-	TDSLOGIN *tds_login;
 	TDSSOCKET *tds_socket;
 	/** statement executing */
 	struct _hstmt *current_statement;
@@ -135,6 +134,8 @@ struct _sql_param_info {
 	char *varaddr;
 	int param_bindlen;
 	SQLINTEGER *param_lenbind;
+	/** this parameter is used if provided param_lenbind is NULL */
+	SQLINTEGER param_inlen;
 	struct _sql_param_info *next;
 };
 
