@@ -54,6 +54,7 @@
 #include "connectparams.h"
 #include "odbc_util.h"
 #include "convert_tds2sql.h"
+#include "convert_sql2string.h"
 #include "sql2tds.h"
 #include "prepare_query.h"
 #include "replacements.h"
@@ -62,7 +63,7 @@
 #include <dmalloc.h>
 #endif
 
-static char software_version[] = "$Id: odbc.c,v 1.131.2.2 2003/02/14 13:19:33 freddy77 Exp $";
+static char software_version[] = "$Id: odbc.c,v 1.131.2.5 2003/08/01 05:27:28 freddy77 Exp $";
 static void *no_unused_var_warn[] = { software_version, no_unused_var_warn };
 
 static SQLRETURN SQL_API _SQLAllocConnect(SQLHENV henv, SQLHDBC FAR * phdbc);
@@ -454,7 +455,21 @@ SQLBindParameter(SQLHSTMT hstmt, SQLUSMALLINT ipar, SQLSMALLINT fParamType, SQLS
 	cur->param_sqltype = fSqlType;
 	if (cur->param_bindtype == SQL_C_CHAR)
 		cur->param_bindlen = cbValueMax;
-	cur->param_lenbind = pcbValue;
+	if (!pcbValue) {
+		cur->param_inlen = 0;
+		cur->param_lenbind = &cur->param_inlen;
+		/* TODO add XML if defined */
+		if (cur->param_bindtype == SQL_C_CHAR || cur->param_bindtype == SQL_C_BINARY) {
+			cur->param_inlen = SQL_NTS;
+		} else {
+			int size = tds_get_size_by_type(odbc_get_server_type(cur->param_bindtype));
+
+			if (size > 0)
+				cur->param_inlen = size;
+		}
+	} else {
+		cur->param_lenbind = pcbValue;
+	}
 	cur->varaddr = (char *) rgbValue;
 
 	return SQL_SUCCESS;
@@ -494,12 +509,6 @@ _SQLAllocConnect(SQLHENV henv, SQLHDBC FAR * phdbc)
 
 	memset(dbc, '\0', sizeof(TDS_DBC));
 	dbc->henv = env;
-	dbc->tds_login = tds_alloc_login();
-	if (!dbc->tds_login) {
-		free(dbc);
-		odbc_errs_add(&env->errs, ODBCERR_MEMORY, NULL);
-		return SQL_ERROR;
-	}
 	/* spinellia@acm.org
 	 * after login is enabled autocommit */
 	dbc->autocommit_state = 1;
@@ -1289,7 +1298,11 @@ static SQLRETURN SQL_API
 _SQLFreeEnv(SQLHENV henv)
 {
 	INIT_HENV;
-	/* TODO why don't free anything ??? */
+
+	tds_free_context(env->tds_ctx);
+	odbc_errs_reset(&env->errs);
+	free(env);
+
 	return SQL_SUCCESS;
 }
 
